#!/bin/bash
MINBIN=/usr/local/minerva/bin

echo
echo Minerva - Installation
echo
echo IMPORTANT - Unless you are familar with the system, it is recommended
echo you install everything.
echo
echo

create_users()
{
   groupadd minerva
   useradd -g minerva minerva
   usermod -G minerva -a www-data
}

do_main_install()
{
   mkdir -p /usr/local/minerva
   cp -a base/*   /usr/local/minerva

   mkdir -p /var/log/minerva/cache
   mkdir -p /var/log/minerva/cosmic

   mkdir -p ~minerva/update
   cp -a update/*  ~minerva/update

   cp -a conf ~minerva
}

do_bearskin_initialize()
{
   if [ -f /usr/local/bin/heyu ]; then
      /usr/local/bin/heyu engine
   fi

   $MINBIN/cdplayer   default init
   $MINBIN/cosmic     default init
   $MINBIN/ctimer     default init
   $MINBIN/mixer      default init
   $MINBIN/mp3player  default init
   $MINBIN/x10control default init   
}

do_web_install()
{
   mkdir -p /var/www/minerva
   cp -a web/* /var/www/minerva

   apache2ctl restart
}

do_tv_install()
{
   pushd conf/tv >/dev/null

   ./make_web.sh
   ./prepare_web.sh

   cp -a stations ~minerva/update/tv

   popd >/dev/null
}

do_daily_update()
{
   pushd conf/tv  >/dev/null
   ~minerva/update/tv/daily_process.sh
   ~minerva/update/weather
   popd
}

do_chmod()
{
   chown -R minerva /var/www/minerva /var/log/minerva ~minerva/update
   chgrp -R minerva /var/www/minerva /var/log/minerva ~minerva/update

   # Ideally, I'd like to only assign +rw to ug, but cosmic/heyu runs
   # the scripts as a user without the group assigned. (but only
   # sometimes :( Solutions are requested ;)
   chmod -R ugo+rw  /var/www/minerva /var/log/minerva ~minerva/update
}

echo Press ENTER to create a user and group called 'minerva'
echo or any other text to skip this step.
echo Note: This will fail if you are not root!
read -p "> "

if [ "$REPLY" == "" ]; then
  create_users;
fi

echo;echo;echo;
echo Press ENTER to copy the base system to /usr/local/minerva
echo and create the /var/log/minerva stubs.
echo Or type any other text to skip this step.
read -p "> "

if [ "$REPLY" == "" ]; then
   do_main_install;
   do_bearskin_initialize;
fi


echo;echo;echo;
echo Please enter the name of each member of the household that will
echo use Minerva. This is needed for the TV guide, amongst other things.
echo You can add new users with the 'addminervauser' command.
echo Press ENTER on its own to terminate.
REPLY=q
while [ "$REPLY" != "" ]
do
read
if [ "$REPLY" != "" ];then
   /usr/local/minerva/bin/addminervauser $REPLY
fi
done


echo;echo;echo;
echo Press ENTER to copy the web components system to /var/www/minerva
echo or any other text to skip this step.
read -p "> "
if [ "$REPLY" == "" ];then
   do_web_install;
fi


echo;echo;echo;
echo Press ENTER to prepare the TV guide web pages
echo or any other text to skip this step.
read -p "> "
if [ "$REPLY" == "" ];then
   do_tv_install;
fi


echo;echo;echo;
echo Press ENTER to run the daily downloads
echo or any other text to skip this step.
echo \(Requires internet connection\)
read -p "> "
if [ "$REPLY" == "" ]; then
   do_daily_update;
fi

do_chmod;

echo;echo;echo;
echo Installation complete!
echo
cat POST_INSTALL

