<?php
require_once 'warp/system/setup.conf';
require_once 'warp/warplib/applet.inc';

class Warp_Logger_Line
{
    var $num;
    var $text;

    var $_mul;
    
    function Warp_Logger_Line($a, $b)
    {
        static $rev = -1;
        
        $this->num = $a;
        $this->text = $b;
  
        // This is a static and identicall across all instances      
        $this->_mul =& $rev;
    }
    
    function setReverseSort($r)
    {
        $this->_mul = $r ? 1 : -1;
    }
    
    // This comparison functions are static, so $this doesn't
    // make sense, we therefore use $a->before & $a->after.
    // However, we could equally well use $b->, since it's
    // static.
    function compareNum($a, $b)
    {
        if ($a->num == $b->num) {
            return 0;
        }
        $v = ($a->num < $b->num) ? -1 : 1;
	return $v * $a->_mul;
    }
    
    function compareText($a, $b)
    {
        $al = strtolower($a->text);
        $bl = strtolower($b->text);
        if ($al == $bl) {
            return 0;
        }
        $v = ($al < $bl) ? -1 : 1;
	return $v * $a->_mul;
    }
}


class Warp_Logger_Applet extends Warp_Applet
{
    var $_maxEntries = 10;	// changeable with config
    var $_sort;
    var $_options;
    var $_replace;
   
    function Warp_Logger_Applet($description, $logFile) 
    {
        parent::__construct($description);

        $this->_logDescription = $description;
        $this->_logFile = $logFile;
    }
 
    function getName()
    {
        return $this->_logDescription;
    }
   

    function getDirectory()
    {
        return "logger";
    }

    function init(&$appMan)
    {
        // pickup any control parameters passed in 
        $max = $appMan->queryParameter($this, "mx");
        if ($max != "" && $max > 0) {
            $this->_maxEntries = $max;
        }

        $opt = $appMan->queryParameter($this, "opt");
        if ($opt != "") {
            $this->_options = $opt;
        }


        if ($_SERVER['REQUEST_METHOD'] == 'POST') {
            // Clear any existing options
            $this->_options = 0;

            // was any config information posted to this page?
            $this->_maxEntries = $_POST["max"];

            if ($_POST["optdot"] != "") { $this->_options += 1; }
            if ($_POST["optund"] != "") { $this->_options += 2; }
            if ($_POST["optmin"] != "") { $this->_options += 4; }

            // Validate
            $this->_maxEntries = max(1, $this->_maxEntries);
        }

        // get default state, if present. (just a sort order)
        $this->_sort = $appMan->queryParameter($this, "sort");
        if ($this->_sort == "") {
            $this->_sort = 11;
        }
        
        // parse sort argument, if present
        $arg = $appMan->queryParameter($this, "do");
        if ($arg != "") {
            $this->_sort = $arg;
        }

        return true;
    }
    
    function renderPanel(&$appMan)
    {
        if (@$fp = &fopen($this->_logFile, "r")) {
            $html = fgets($fp, 1024);
            $html = htmlspecialchars($html);
            fclose($fp);
        }
        
        return $html;
    }

    function processLogFileLine($line, $regexOptions)
    {
       if ($regexOptions != "/[]/") {
          $line = preg_replace($regexOptions, " ", $line);
       }
       return $line;
    }
    
    function renderWindow(&$appMan)
    {
        if (!file_exists($this->_logFile)) {
            return "No log file...";
        }
        
        $lines = file($this->_logFile);
        $loglist = array();
        
        // build a regex to remove duff charcaters
        $regex = "/[";
        if ($this->_options & 1) { $regex .= "\."; }
        if ($this->_options & 2) { $regex .= "_"; }
        if ($this->_options & 4) { $regex .= "-"; }
        $regex .= "]/";

        $total = 1;
        foreach($lines as $num => $line)
        {
           $line = $this->processLogFileLine($line, $regex);
           $loglist[] = new Warp_Logger_Line($total, $line);
           ++$total;
        }
        
        $loglist[0]->setReverseSort(($this->_sort & 1)?true:false);
        
        // Which column are we sorting?
        switch ((int)($this->_sort / 10)) {
        case    2:
            $sortParam = "compareText";
            break;
        case    1:
            default:
            $sortParam = "compareNum";
        }
        
        // Do the sort
        uasort($loglist, array("Warp_Logger_Line", $sortParam));
        
        $html = "<table width=100% cellspacing=5><tr valign=center bgcolor=#dddddd>";
        $html.= "<td><b>#</b> ";
        $html.= $appMan->getAppletLink($this, "do", "10", $appMan->getStyleText("down"));
        $html.= $appMan->getAppletLink($this, "do", "11", $appMan->getStyleText("up"));
        
        $html.= "</td><td><b>Filename</b> ";
        $html.= $appMan->getAppletLink($this, "do", "20", $appMan->getStyleText("down"));
        $html.= $appMan->getAppletLink($this, "do", "21", $appMan->getStyleText("up"));
        $html.= "</td></tr>\n";
        
        $count = 0;
        foreach($loglist as $num => $log)
        {
            $html.="<tr><td><b>$log->num</b></td><td>".($log->text)."</td></tr>\n";
            if (++$count >= $this->_maxEntries) {
               break;
            }
        }
        $html.="</table>";
        
        
        return $html;
    }
    
    function getRefreshParams(&$appMan)
    {
        $refresh  = $appMan->getArgument($this, "sort", $this->_sort);
        $refresh .= "&".$appMan->getArgument($this, "mx", $this->_maxEntries);
        $refresh .= "&".$appMan->getArgument($this, "opt", $this->_options);
        return $refresh;
    }

    function renderConfig(&$appMan)
    {
        //$html  = "<form action=".$appMan->getRefreshURL();
        $html  = "<form action=".$appMan->getMaximiseURL($this->getID($appMan));
        $html .= " method=post enctype=application/x-www-form-urlencoded>";
        $html .= "<br>Visible Entries: <input type=text name=max value=".$this->_maxEntries.">";
        $html .= "<br><br>";
        $html .= "Use spaces instead of...<br>";
        $html .= "&nbsp;dots : <input type=checkbox name=optdot ".($this->_options&1?"checked":"").">";
        $html .= "&nbsp;underscores: <input type=checkbox name=optund ".($this->_options&2?"checked":"").">";
        $html .= "&nbsp;hypens: <input type=checkbox name=optmin ".($this->_options&4?"checked":"").">";

        $html .= "<br><br><INPUT TYPE=submit VALUE=Apply>";
        $html .= "<br></form><br>";
        return $html;
    }

    function renderInfo(&$app_man, $fast=false)
    {
        if ($fast) {
            return "-";
        }

        return <<<EOD
<p>This reads the information in a given file, and lists each line on a
separate row. You can sort on the row index, or the text on the line. Good
for logs, as the name suggests.</p>
<p>The specific log file is passed as an argument when constructing the applet.
e.g.</p>
<pre>
$appman->AddApplet(new Warp_Logger_Applet("X10 Heyu", "/var/log/heyu/heyu.log.ttyS0"));
</pre>
EOD;
    }

}

?>
